==> mdb-vue-ui-kit-1.7.0.tgz: package/README.md <==
![MDB Logo](https://mdbootstrap.com/img/Marketing/general/logo/medium/mdb-vue.png)

# MDB 5 Vue

### Vue 3 & Bootstrap 5 & Material Design 2.0 UI KIT

**[>> Get Started in 4 steps](https://mdbootstrap.com/docs/b5/vue/getting-started/installation/)**

**[>> MDBVue 5 Demo](https://mdbootstrap.com/docs/b5/vue#demo)**

<a href="https://npmcharts.com/compare/mdb-vue-ui-kit?minimal=true"> <img src="https://img.shields.io/npm/dw/mdb-vue-ui-kit" alt="Downloads"></a>
<a href="https://github.com/mdbootstrap/mdb-vue-ui-kit/License.pdf"><img src="https://img.shields.io/badge/license-MIT-green.svg" alt="License"></a>
<a href="https://twitter.com/intent/tweet/?text=Thanks+@mdbootstrap+for+creating+amazing+and+free+Material+Design+for+Bootstrap+4+UI+KIT%20https://mdbootstrap.com/docs/jquery/&hashtags=javascript,code,webdesign,bootstrap"><img src="https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Let%20us%20know%20you%20were%20here%21&"></a>
<a href="https://www.youtube.com/watch?v=c9B4TPnak1A&t=6s"><img alt="YouTube Video Views" src="https://img.shields.io/youtube/views/c9B4TPnak1A?label=Bootstrap%205%20Tutorial%20Views&style=social"></a>

---

 <a href="https://mdbootstrap.com/bf/waiting-list/" alt="BF Waiting List" rel="dofollow">
          		<img src="https://mdbootstrap.com/img/Marketing/campaigns/bf2021/waiting-listBF.gif">
          </a>
          
---

<table>
  <tbody>
    <tr>
      <td>
          <a href="https://mdbootstrap.com/docs/b5/vue/" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/themes/mdbootstrap4/content/en/_mdb5/standard/about/assets/mdb5-about.jpg">
          </a>
      </td>
      <td>
        <ul>
        <li><b>500+ material UI components</b></li>
         <li>Super simple, 1 minute installation</li>
         <li>Detailed docs & multiple practical examples</li>
         <li>Vue 3</li>
         <li>Huge and active community</li>
         <li><b>MIT license - free for personal & commercial use</b></li>
        </ul>
      </td>
    </tr>
   </tbody>
</table>

Trusted by <b>2 000 000+</b> developers & designers. Used by companies like

<table>
  <tbody>
    <tr>
      <td><img src="https://mdbootstrap.com/img/logo/brands/nike.png" style="width: 10px;"></td>
      <td><img src="https://mdbootstrap.com/img/logo/brands/amazon.png" style="width: 10px;"></td>
      <td><img src="https://mdbootstrap.com/img/logo/brands/sony.png" style="width: 10px;"></td>
      <td><img src="https://mdbootstrap.com/img/logo/brands/samsung.png"  style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/airbus.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/yahoo.png"  style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/deloitte.png" style="height: 40px"></div>
      <td><img src="https://mdbootstrap.com/img/logo/brands/ge.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/kpmg.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/unity.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/ikea.png" style="max-height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/aegon.png" style="height: 40px">
    </tr>
   </tbody>
</table>

---

###### Tutorial for the latest Bootstrap v.5 Alpha. In this video we'll learn about the changes implemented into v.5.

**[>> Click here for a written tutorial](https://mdbootstrap.com/docs/b5/vue/getting-started/quick-start/)**

<table>
  <tbody>
    <tr>
      <td align="center">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/learnmore-1.png">
          </a>
      </td>
      <td>
          <a href="https://mdbootstrap.com/docs/standard/bootstrap-5-tutorial/#section-beginner" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/cover-bootstrap-5-1.png">
          </a>
      </td>
    </tr>
     <tr>
        <td align="center">
          <p align="center"><b>Start to Code</b></p>
          <a href="https://mdbootstrap.com/docs/standard/bootstrap-5-tutorial/#section-beginner" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/Screenshot_26.png">
          </a>
         </td>
        <td align="center">
          <p align="center"><b>Learn Bootstrap 5 | Crash Course for Beginners in 1.5H</b></p>
          <a href="https://mdbootstrap.com/docs/standard/bootstrap-5-tutorial/#section-beginner" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/Screenshot_26.png">
          </a>
         </td>
      </tr>
   </tbody>
</table>

---

# Demo

#### Simplicity and ease of use are key features of MDB 5 Vue UI Kit. You need only one minute to install and run it.

### Buttons

<p>Use MDB custom button styles for actions in forms, dialogs, and more with support for multiple sizes, states, and more.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-buttons.gif">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-social-buttons.png">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-buttons2.png">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-buttons-outline.gif">
  </p>
</a>

### Spinners

<p>Indicate the loading state of a component or page with MDB spinners, built entirely with HTML, CSS, and no JavaScript.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/components/spinners/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-loader.gif">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/spinners/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-color-spinners.gif">
  </p>
</a>

### Cards

<p>A card is a flexible and extensible content container. It includes options for headers and footers, a wide variety of content, contextual background colors, and powerful display options.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/components/cards/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-cards.png">
  </p>
</a>

### Footer

<p>A footer is an additional navigation component. It can hold links, buttons, company info, copyrights, forms, and many other elements.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/navigation/footer/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-footer.png">
  </p>
</a>

### Hover

<p>MDB hover effect appears when the user positions the computer cursor over an element without activating it. Hover effects make a website more interactive.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/content-styles/hover-effects/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-hover.gif">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/content-styles/hover-effects/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-hover2.png">
  </p>
</a>

### Notes

<p>Notes are small components very helpful in inserting an additional piece of information.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/content-styles/typography/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-alerts.png">
  </p>
</a>

</table>

and more.

==> mdb-vue-ui-kit-1.8.0.tgz: package/README.md <==
![MDB Logo](https://mdbootstrap.com/img/Marketing/general/logo/medium/mdb-vue.png)

# MDB 5 Vue

### Vue 3 & Bootstrap 5 & Material Design 2.0 UI KIT

**[>> Get Started in 4 steps](https://mdbootstrap.com/docs/b5/vue/getting-started/installation/)**

**[>> MDBVue 5 Demo](https://mdbootstrap.com/docs/b5/vue#demo)**

<a href="https://npmcharts.com/compare/mdb-vue-ui-kit?minimal=true"> <img src="https://img.shields.io/npm/dw/mdb-vue-ui-kit" alt="Downloads"></a>
<a href="https://github.com/mdbootstrap/mdb-vue-ui-kit/License.pdf"><img src="https://img.shields.io/badge/license-MIT-green.svg" alt="License"></a>
<a href="https://twitter.com/intent/tweet/?text=Thanks+@mdbootstrap+for+creating+amazing+and+free+Material+Design+for+Bootstrap+4+UI+KIT%20https://mdbootstrap.com/docs/jquery/&hashtags=javascript,code,webdesign,bootstrap"><img src="https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Let%20us%20know%20you%20were%20here%21&"></a>
<a href="https://www.youtube.com/watch?v=c9B4TPnak1A&t=6s"><img alt="YouTube Video Views" src="https://img.shields.io/youtube/views/c9B4TPnak1A?label=Bootstrap%205%20Tutorial%20Views&style=social"></a>

---

 <a href="https://mdbootstrap.com/bf/sale/" alt="BF Waiting List" rel="dofollow">
          		<img src="https://mdbcdn.b-cdn.net/img/Marketing/campaigns/bf2021/black-friday-sale.gif">
          </a>
          
---

<table>
  <tbody>
    <tr>
      <td>
          <a href="https://mdbootstrap.com/docs/b5/vue/" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/themes/mdbootstrap4/content/en/_mdb5/standard/about/assets/mdb5-about.jpg">
          </a>
      </td>
      <td>
        <ul>
        <li><b>500+ material UI components</b></li>
         <li>Super simple, 1 minute installation</li>
         <li>Detailed docs & multiple practical examples</li>
         <li>Vue 3</li>
         <li>Huge and active community</li>
         <li><b>MIT license - free for personal & commercial use</b></li>
        </ul>
      </td>
    </tr>
   </tbody>
</table>

Trusted by <b>2 000 000+</b> developers & designers. Used by companies like

<table>
  <tbody>
    <tr>
      <td><img src="https://mdbootstrap.com/img/logo/brands/nike.png" style="width: 10px;"></td>
      <td><img src="https://mdbootstrap.com/img/logo/brands/amazon.png" style="width: 10px;"></td>
      <td><img src="https://mdbootstrap.com/img/logo/brands/sony.png" style="width: 10px;"></td>
      <td><img src="https://mdbootstrap.com/img/logo/brands/samsung.png"  style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/airbus.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/yahoo.png"  style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/deloitte.png" style="height: 40px"></div>
      <td><img src="https://mdbootstrap.com/img/logo/brands/ge.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/kpmg.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/unity.png" style="height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/ikea.png" style="max-height: 40px">
      <td><img src="https://mdbootstrap.com/img/logo/brands/aegon.png" style="height: 40px">
    </tr>
   </tbody>
</table>

---

###### Tutorial for the latest Bootstrap v.5 Alpha. In this video we'll learn about the changes implemented into v.5.

**[>> Click here for a written tutorial](https://mdbootstrap.com/docs/b5/vue/getting-started/quick-start/)**

<table>
  <tbody>
    <tr>
      <td align="center">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/learnmore-1.png">
          </a>
      </td>
      <td>
          <a href="https://mdbootstrap.com/docs/standard/bootstrap-5-tutorial/#section-beginner" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/cover-bootstrap-5-1.png">
          </a>
      </td>
    </tr>
     <tr>
        <td align="center">
          <p align="center"><b>Start to Code</b></p>
          <a href="https://mdbootstrap.com/docs/standard/bootstrap-5-tutorial/#section-beginner" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/Screenshot_26.png">
          </a>
         </td>
        <td align="center">
          <p align="center"><b>Learn Bootstrap 5 | Crash Course for Beginners in 1.5H</b></p>
          <a href="https://mdbootstrap.com/docs/standard/bootstrap-5-tutorial/#section-beginner" alt="Bootstrap 5" rel="dofollow">
          		<img src="https://mdbootstrap.com/wp-content/uploads/2020/12/Screenshot_26.png">
          </a>
         </td>
      </tr>
   </tbody>
</table>

---

# Demo

#### Simplicity and ease of use are key features of MDB 5 Vue UI Kit. You need only one minute to install and run it.

### Buttons

<p>Use MDB custom button styles for actions in forms, dialogs, and more with support for multiple sizes, states, and more.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-buttons.gif">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-social-buttons.png">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-buttons2.png">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/buttons/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-buttons-outline.gif">
  </p>
</a>

### Spinners

<p>Indicate the loading state of a component or page with MDB spinners, built entirely with HTML, CSS, and no JavaScript.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/components/spinners/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-loader.gif">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/components/spinners/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-color-spinners.gif">
  </p>
</a>

### Cards

<p>A card is a flexible and extensible content container. It includes options for headers and footers, a wide variety of content, contextual background colors, and powerful display options.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/components/cards/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-cards.png">
  </p>
</a>

### Footer

<p>A footer is an additional navigation component. It can hold links, buttons, company info, copyrights, forms, and many other elements.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/navigation/footer/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-footer.png">
  </p>
</a>

### Hover

<p>MDB hover effect appears when the user positions the computer cursor over an element without activating it. Hover effects make a website more interactive.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/content-styles/hover-effects/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-hover.gif">
  </p>
</a>

<a href="https://mdbootstrap.com/docs/b5/vue/content-styles/hover-effects/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-hover2.png">
  </p>
</a>

### Notes

<p>Notes are small components very helpful in inserting an additional piece of information.</p>

<a href="https://mdbootstrap.com/docs/b5/vue/content-styles/typography/" alt="Bootstrap 5" rel="dofollow">
  <p align="center">
    <img src="https://mdbootstrap.com/img/Marketing/campaigns/demo-alerts.png">
  </p>
</a>

</table>

and more.
